@@ -23,8 +23,6 @@
 # include "tdep-x86/libunwind_i.h"
 #elif defined __x86_64__
 # include "tdep-x86_64/libunwind_i.h"
-#elif defined __tilegx__
-# include "tdep-tilegx/libunwind_i.h"
 #elif defined __s390x__
 # include "tdep-s390x/libunwind_i.h"
 #elif defined __riscv || defined __riscv__
