@@ -38,6 +38,7 @@ tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
 {
   struct load_module_desc lmd;
   const char *path2;
+  int ret;
 
   if (pid != getpid ())
     {
@@ -63,5 +64,20 @@ tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
     }
   Debug(1, "segbase=%lx, mapoff=%lx, path=%s\n", *segbase, *mapoff, path);
 
-  return elf_map_image (ei, path);
+  if (ei)
+    ret = elf_map_image (ei, path);
+  else
+    ret = strlen (path2) >= path ? -UNW_ENOMEM : UNW_ESUCCESS;
+  return ret;
 }
+
+#ifndef UNW_REMOTE_ONLY
+
+void
+tdep_get_exe_image_path (char *path)
+{
+  path[0] = 0; /* XXX */
+}
+
+#endif
+
