@@ -25,6 +25,10 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 
 #include <limits.h>
 #include <stdio.h>
+#include <sys/stat.h>
+#include <string.h>
+#include <stdlib.h>
+#include <assert.h>
 
 #include "libunwind_i.h"
 #include "os-linux.h"
@@ -35,13 +39,16 @@ tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
                     char *path, size_t pathlen)
 {
   struct map_iterator mi;
-  int found = 0, rc;
+  int found = 0, rc = UNW_ESUCCESS;
   unsigned long hi;
+  char root[sizeof ("/proc/0123456789/root")], *cp;
+  char *full_path;
+  struct stat st;
 
   if (maps_init (&mi, pid) < 0)
     return -1;
 
-  while (maps_next (&mi, segbase, &hi, mapoff))
+  while (maps_next (&mi, segbase, &hi, mapoff, NULL))
     if (ip >= *segbase && ip < hi)
       {
         found = 1;
@@ -53,11 +60,53 @@ tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
       maps_close (&mi);
       return -1;
     }
-  if (path)
+
+  // get path only, no need to map elf image
+  if (!ei && path)
     {
       strncpy(path, mi.path, pathlen);
+      path[pathlen - 1] = '\0';
+      if (strlen(mi.path) >= pathlen)
+        rc = -UNW_ENOMEM;
+
+      maps_close (&mi);
+      return rc;
     }
-  rc = elf_map_image (ei, mi.path);
+
+  full_path = mi.path;
+
+  /* Get process root */
+  memcpy (root, "/proc/", 6);
+  cp = unw_ltoa (root + 6, pid);
+  assert (cp + 6 < root + sizeof (root));
+  memcpy (cp, "/root", 6);
+
+  size_t _len = strlen (mi.path) + 1;
+  if (!stat(root, &st) && S_ISDIR(st.st_mode))
+    _len += strlen (root);
+  else
+    root[0] = '\0';
+
+  full_path = path;
+  if(!path)
+    full_path = (char*) malloc (_len);
+  else if(_len >= pathlen) // passed buffer is too small, fail
+    {
+      maps_close (&mi);
+      return -1;
+    }
+
+  strcpy (full_path, root);
+  strcat (full_path, mi.path);
+
+  if (stat(full_path, &st) || !S_ISREG(st.st_mode))
+    strcpy(full_path, mi.path);
+
+  rc = elf_map_image (ei, full_path);
+
+  if (!path)
+    free (full_path);
+
   maps_close (&mi);
   return rc;
 }
