@@ -1,4 +1,5 @@
-#ifndef UNW_REMOTE_ONLY
 #define UNW_LOCAL_ONLY
+#include <libunwind.h>
+#if !defined(UNW_REMOTE_ONLY)
 #include "Gtest-exc.c"
 #endif
